@@ -14,7 +14,7 @@ use URI::Escape;
 
 use vars qw( $VERSION );
 
-$VERSION = '0.79';
+$VERSION = '0.80';
 
 =head1 NAME
 
@@ -619,7 +619,7 @@ sub preview_edit {
                                                set_coord_field_vars => 1,
     );
     foreach my $var ( qw( username comment edit_type ) ) {
-        $new_metadata{$var} = $q->escapeHTML($q->param($var));
+        $new_metadata{$var} = $q->escapeHTML(scalar $q->param($var));
     }
 
     if ($wiki->verify_checksum($node, $checksum)) {
