@@ -2,7 +2,7 @@ package OpenGuides::Utils;
 
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 use Carp qw( croak );
 use Wiki::Toolkit;
@@ -531,7 +531,7 @@ sub validate_edit {
     }
 
     if ( $q->param('website') and $q->param('website') ne 'http://' ) {
-        unless ( is_web_uri( $q->param('website') ) ) {
+        unless ( is_web_uri( scalar $q->param('website') ) ) {
             push @fails, $q->param('website') . ' is not a valid web URI';
         }
     }
